searchData={"items":[{"type":"module","title":"Emoshi","doc":"Main module to query and access emoji data.\n\nSee https://www.unicode.org/reports/tr51/ for information about emojis.","ref":"Emoshi.html"},{"type":"function","title":"Emoshi.closest/2","doc":"Returns the closest emojis by slug.\n\nUses `String.jaro_distance/2` internally to find the closest emojis.","ref":"Emoshi.html#closest/2"},{"type":"function","title":"Options - Emoshi.closest/2","doc":"* `:ignore_variations` - `t:boolean/0`. Whether to ignore variations such as skin color.\n  Defaults to `true`.\n* `:take`- `t:pos_integer/0`. The number of emojis to retrieve.\n  Defaults to `5`","ref":"Emoshi.html#closest/2-options"},{"type":"type","title":"Emoshi.emoji_status/0","doc":"","ref":"Emoshi.html#t:emoji_status/0"},{"type":"function","title":"Emoshi.for_group/1","doc":"Returns all emojis for the given group","ref":"Emoshi.html#for_group/1"},{"type":"function","title":"Emoshi.for_groups/1","doc":"Returns all emojis for the given groups","ref":"Emoshi.html#for_groups/1"},{"type":"function","title":"Emoshi.for_subgroups/2","doc":"Returns all emojis for the given group and subgroup(s).\n\nAccepts both a single subgroup and a list of subgroups","ref":"Emoshi.html#for_subgroups/2"},{"type":"function","title":"Emoshi.group?/1","doc":"Returns whether an emoji group exists","ref":"Emoshi.html#group?/1"},{"type":"function","title":"Emoshi.groups/0","doc":"Returns all the emojis' groups","ref":"Emoshi.html#groups/0"},{"type":"function","title":"Emoshi.search/2","doc":"Returns all `t:Emoshi.t/0` where the slug matches the input argument.\n\nUnlike `closest/2` this function checks for substring comparison.","ref":"Emoshi.html#search/2"},{"type":"function","title":"Options - Emoshi.search/2","doc":"* `:ignore_variations` - `t:boolean/0`. Whether to ignore variations such as skin color.\nDefaults to `true`.\n* `:take` - `t:pos_integer/0`. The maximum number of emojis to retrieve. Keep in mind\nthat unlike `closest/2` which always returns the specified `:take` number, this function\nmay return fewer results if there are not enough matches.\nDefaults to `5`","ref":"Emoshi.html#search/2-options"},{"type":"function","title":"Emoshi.subgroups/1","doc":"Returns all the subgroups for a group or `nil` if the group does not exist","ref":"Emoshi.html#subgroups/1"},{"type":"type","title":"Emoshi.t/0","doc":"","ref":"Emoshi.html#t:t/0"},{"type":"function","title":"Emoshi.version/0","doc":"Returns the specs version used to generate the module","ref":"Emoshi.html#version/0"},{"type":"extras","title":"README","doc":"[![CI](https://github.com/IgnacioGoldchluk/emoshi/actions/workflows/ci.yml/badge.svg)](https://github.com/IgnacioGoldchluk/emoshi/actions/workflows/ci.yml)\n[![License](https://img.shields.io/hexpm/l/emoshi.svg)](https://github.com/IgnacioGoldchluk/emoshi/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/emoshi.svg)](https://hex.pm/packages/emoshi)\n[![Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/emoshi)\n\n# Emoshi\n\nElixir library for accessing emojis.\n\nThis library's list of emojis is generated from the official [emoji data set](https://www.unicode.org/Public/emoji/latest/emoji-test.txt)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"Add `emoshi` to your list of dependencies in `mix.exs`:\n```elixir\ndef deps do\n  [\n    {:emoshi, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic usage - README","doc":"1. Searching an emoji by name\n```elixir\niex> Emoshi.search(\"thumbs\", take: 2)\n[\n  %Emoshi{\n    slug: \"thumbs-up\",\n    name: \"thumbs up\",\n    status: :fully_qualified,\n    emoji: \"👍\",\n    group: \"People & Body\",\n    subgroup: \"hand-fingers-closed\"\n  },\n  %Emoshi{\n    slug: \"thumbs-down\",\n    name: \"thumbs down\",\n    status: :fully_qualified,\n    emoji: \"👎\",\n    group: \"People & Body\",\n    subgroup: \"hand-fingers-closed\"\n  }\n]\n```\n\n2. Fuzzy search\n```elixir\niex(1)> Emoshi.closest(\"tubms up\", take: 1)\n[\n  %Emoshi{\n    slug: \"thumbs-up\",\n    name: \"thumbs up\",\n    status: :fully_qualified,\n    emoji: \"👍\",\n    group: \"People & Body\",\n    subgroup: \"hand-fingers-closed\"\n  }\n]\n```\n\n3. Querying by group\n```elixir\niex(2)> Emoshi.for_subgroups(\"Travel & Places\", \"hotel\")\n[\n  %Emoshi{\n    slug: \"bellhop-bell\",\n    name: \"bellhop bell\",\n    status: :fully_qualified,\n    emoji: \"🛎️\",\n    group: \"Travel & Places\",\n    subgroup: \"hotel\"\n  },\n  %Emoshi{\n    slug: \"luggage\",\n    name: \"luggage\",\n    status: :fully_qualified,\n    emoji: \"🧳\",\n    group: \"Travel & Places\",\n    subgroup: \"hotel\"\n  }\n]\n```\n\nRefer to the [full documentation](https://hexdocs.pm/emoshi) for a more comprehensive description of the library's functionality","ref":"readme.html#basic-usage"},{"type":"extras","title":"Design and contributing - README","doc":"The main goal of this library is to provide the parsed emoji dataset as an Elixir package.\n\nThe approach of including the raw data set (either as text, json, or any format) and parsing it during runtime or during module compilation brings unnecessary dependencies and slows down application startup or application compilation times. This package aims to be as light as possible and currently contains no dependencies for production usage.\n\nThe reason to place the data module separately from the functionality module is simply to keep it IDE-friendly, since working on the main [`Emoshi`](./lib/emoshi.ex) module while having the entire emoji dataset in the same file would be slow and a poor developer experience.","ref":"readme.html#design-and-contributing"},{"type":"extras","title":"Code generation - README","doc":"The full emoji dataset is downloaded from the official source via [`mix download_emojis`](./tasks/download_emojis.ex]). The file is then parsed and the data module is generated at [`Emoshi.Emoshis`](./lib/emoshi/emoshis.ex) via [`mix generate_emojis`](./tasks/generate_emojis.ex). An alias is available to run these 2 tasks as `mix download_and_generate`.","ref":"readme.html#code-generation"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}